runInShell property

bool runInShell
final

If set to true, the process will run be spawned through a system shell.

Running in a shell is generally not recommended, as it provides worse performance, and some security risk, but is sometimes necessary for accessing the shell environment. Shell command line expansion and interpolation is not performed on the commands, but you can execute shell builtins. Use the shell builtin "eval" (on Unix systems) if you want to execute shell commands with expansion.

On Linux and OS X, /bin/sh is used, while on Windows, %WINDIR%\system32\cmd.exe is used.

Defaults to false.

Implementation

final bool runInShell;